﻿/*
 * Copyright 2011 NEHTA
 *
 * Licensed under the NEHTA Open Source (Apache) License; you may not use this
 * file except in compliance with the License. A copy of the License is in the
 * 'license.txt' file, which should be provided with this work.
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */

using System.Collections.Generic;
using JetBrains.Annotations;
using Nehta.VendorLibrary.CDA.Common;
using Nehta.VendorLibrary.CDA.SCSModel.Common;
using Nehta.VendorLibrary.Common;

namespace Nehta.VendorLibrary.CDA.SCSModel
{
    /// <summary>
    /// The IObservationWeightHeight interface constrains the IObservation interface down to only those
    /// properties that relate to an individulas height and weight
    /// </summary>
    [OID(OID = "1.2.36.1.2001.1001.101.101.16280", Identifier = "S-16280")]
    public interface IObservationWeightHeight
    {
        /// <summary>
        /// Body weight
        /// </summary>
        [CanBeNull]
        [OID(OID = "1.2.36.1.2001.1001.101.102.16124", Identifier = "DG-16124")]
        BodyWeight BodyWeight { get; set; }

        /// <summary>
        /// Body height
        /// </summary>
        [CanBeNull]
        [OID(OID = "1.2.36.1.2001.1001.101.102.16123", Identifier = "DG-16123")]
        BodyHeight BodyHeight { get; set; }

        /// <summary>
        /// Validates this CDA Context for this Observation Weight Height
        /// </summary>
        /// <param name="path">The path to this object as a string</param>
        /// <param name="messages">the validation messages, these may be added to within this method</param>
        void Validate(string path, List<ValidationMessage> messages);
    }
}
